/// <reference types="node" />
/// <reference types="node" />
/// <reference types="node" />
/// <reference types="@adonisjs/drive/build/adonis-typings" />
import { Visibility, DriveFileStats, AzureStorageDriverConfig, AzureStorageDriverContract } from '@ioc:Adonis/Core/Drive';
import { BlobServiceClient, BlobDownloadOptions, BlobDownloadToBufferOptions, BlobExistsOptions, BlobSASSignatureValues, BlockBlobUploadOptions, BlockBlobUploadStreamOptions, ContainerCreateOptions, ContainerDeleteMethodOptions, ContainerExistsOptions, ContainerCreateResponse, ContainerDeleteResponse, BlockBlobClient } from '@azure/storage-blob';
import { ReadStream } from 'fs';
export declare class AzureStorageDriver implements AzureStorageDriverContract {
    private config;
    /**
     * Reference to the Azure storage instance
     */
    adapter: BlobServiceClient;
    /**
     * Name of the driver
     */
    name: 'AzureStorage';
    constructor(config: AzureStorageDriverConfig);
    getBlockBlobClient(location: string): BlockBlobClient;
    generateBlobSASURL(blockBlobClient: BlockBlobClient, options: BlobSASSignatureValues): Promise<string>;
    existsContainer(container: string, options?: ContainerExistsOptions): Promise<boolean>;
    /**
     * Creates a new container under the specified account. If the container with the same name already exists, the operation fails.
     * @param container A container name
     * @param options Options to Container Create operation.
     * @returns
     */
    createContainer(container: string, options?: ContainerCreateOptions): Promise<ContainerCreateResponse>;
    /**
     * Marks the specified container for deletion. The container and any blobs contained within it are later deleted during garbage collection.
     * @param container A container name
     * @param options Options to Container Delete operation.
     * @returns
     */
    deleteContainer(container: string, options?: ContainerDeleteMethodOptions): Promise<ContainerDeleteResponse>;
    /**
     * Returns the file contents as a buffer. The buffer return
     * value allows you to self choose the encoding when
     * converting the buffer to a string.
     */
    get(location: string, options?: BlobDownloadToBufferOptions | any): Promise<Buffer>;
    /**
     * Returns the file contents as a stream
     */
    getStream(location: string, options?: BlobDownloadOptions | any): Promise<NodeJS.ReadableStream>;
    /**
     * A boolean to find if the location path exists or not
     */
    exists(location: string, options?: BlobExistsOptions | any): Promise<boolean>;
    /**
     * Returns the signed url for a given path
     */
    getSignedUrl(location: string, options?: BlobSASSignatureValues): Promise<string>;
    /**
     * Returns URL to a given path
     */
    getUrl(location: string): Promise<string>;
    /**
     * Write string|buffer contents to a destination. The missing
     * intermediate directories will be created (if required).
     *
     * @todo look into returning the response of upload
     */
    put(location: string, contents: Buffer | string, options?: BlockBlobUploadOptions | undefined): Promise<void>;
    /**
     * Write a stream to a destination. The missing intermediate
     * directories will be created (if required).
     */
    putStream(location: string, contents: ReadStream, options?: BlockBlobUploadStreamOptions): Promise<void>;
    /**
     * Copy a given location path from the source to the desination.
     * The missing intermediate directories will be created (if required)
     *
     * @todo look into returning the response of syncCopyFromURL
     */
    copy(source: string, destination: string, options?: BlobSASSignatureValues): Promise<void>;
    /**
     * Remove a given location path
     *
     * @todo find a way to extend delete with BlobDeleteOptions
     */
    delete(location: string): Promise<void>;
    /**
     * Move a given location path from the source to the desination.
     * The missing intermediate directories will be created (if required)
     */
    move(source: string, destination: string, options?: BlobSASSignatureValues): Promise<void>;
    /**
     * Returns the file stats
     */
    getStats(location: string): Promise<DriveFileStats>;
    /**
     * Not Supported
     *
     * Returns the file visibility
     *
     */
    getVisibility(location: string): Promise<Visibility>;
    /**
     * Not supported
     *
     * Sets the file visibility
     */
    setVisibility(location: string): Promise<void>;
}
